@@ -291,7 +291,7 @@ var ElementLine = Element.extend({
         // are added later. But this container gets all event handlers assigned. Because
         // the line is using erase(), render(), draw() within place() which is called while
         // the user moves the object, this dom node must not be re-created, because this
-        // would remove all event handlers 
+        // would remove all event handlers
         if (!this.obj.trigger_obj) {
             var oLink = document.createElement('a');
             oLink.setAttribute('id', this.obj.conf.object_id+'-linelink');
@@ -340,6 +340,16 @@ var ElementLine = Element.extend({
         var xEnd   = x[x.length - 1];
         var yEnd   = y[y.length - 1];
 
+        let adjustedPoints = this.cutLineBeyondViewport(xStart, yStart, xEnd, yEnd);
+        if (adjustedPoints === null) {
+            return; // Line won't be visible -> this.parts left empty -> no rendering
+        }
+
+        xStart = adjustedPoints[0];
+        yStart = adjustedPoints[1];
+        xEnd = adjustedPoints[2];
+        yEnd = adjustedPoints[3];
+
         var width = addZoomFactor(this.obj.conf.line_width);
         if (width <= 0)
             width = 1; // minimal width for lines
@@ -422,6 +432,10 @@ var ElementLine = Element.extend({
     },
 
     renderLine: function() {
+        if (this.parts.length === 0) {
+            return;
+        }
+
         var allX = [], allY = [];
         for (var i = 0, len = this.parts.length; i < len; i++) {
             allX = allX.concat(this.parts[i][2]);
@@ -641,6 +655,11 @@ var ElementLine = Element.extend({
     },
 
     renderLabel: function(id) {
+	if (this.parts.length === 0)
+	    return;
+	if (this.perfdata === null)
+            return;
+
         var x1 = this.parts[id][0][0],
             y1 = this.parts[id][0][1],
             x2 = this.parts[id][1][0],
@@ -652,9 +671,6 @@ var ElementLine = Element.extend({
         var x = middle(x1, x2, cut),
             y = middle(y1, y2, cut);
 
-        if (this.perfdata === null)
-            return;
-
         var txt;
         if (this.obj.conf.line_type == 13 || this.obj.conf.line_type == 14) {
             // Show percentage label
@@ -748,7 +764,7 @@ var ElementLine = Element.extend({
         // and maximum values given to be able to calculate the percentage usage
         if (perf[0][2] === null || perf[0][2] === ''
            || perf[1][2] === null || perf[1][2] === '') {
-            perf = this.calculateUsage(perf);
+            perf = this.calculateUsage(perf, this.obj.conf.output);
         }
 
         this.perfdata = perf;
@@ -763,7 +779,7 @@ var ElementLine = Element.extend({
             return oStates["ERROR"].color;
 
         if (!this.perfdata)
-            return '#FFCC66';
+            return oStates["CRITICAL"].color;
 
         if (this.perfdata[id][2] == '%' && this.perfdata[id][1] !== null) {
             return this.getColorFill(this.perfdata[id][1]);
@@ -797,21 +813,29 @@ var ElementLine = Element.extend({
      * with an empty UOM. If found it uses the current value and max value
      * for calculating the percentage usage and also the current usage.
      */
-    calculateUsage: function(oldPerfdata) {
+    calculateUsage: function(oldPerfdata, output) {
         var newPerfdata = [];
         var foundNew = false;
+        var line_label_in = 'in';
+        var line_label_out = 'out';
 
-        // Check_MK if/if64 checks support switching between bytes/bits. The detection
-        // can be made by some curios hack. The most hackish hack I've ever seen. From hell.
-        // Well, let's deal with it.
+        // Check_MK if/if64 checks support switching between bytes/bits.
         var display_bits = false;
-        if(oldPerfdata.length >= 11 && oldPerfdata[10][5] == '0.0')
-            display_bits = true;
+
+        if (output.match('In: [0-9].*bit/s.*Out: [0-9]+')) {
+            display_bits=true;
+        }
 
         // This loop takes perfdata with the labels "in" and "out" and uses the current value
         // and maximum values to parse the percentage usage of the line
+        if (typeof this.obj.conf.line_label_in !== 'undefined') {
+            line_label_in = this.obj.conf.line_label_in;
+        }
+        if (typeof this.obj.conf.line_label_out !== 'undefined') {
+            line_label_out = this.obj.conf.line_label_out;
+        }
         for(var i = 0; i < oldPerfdata.length; i++) {
-            if(oldPerfdata[i][0] == 'in' && (oldPerfdata[i][2] === null || oldPerfdata[i][2] === '')) {
+            if(oldPerfdata[i][0] == line_label_in && (oldPerfdata[i][2] === null || oldPerfdata[i][2] === '')) {
                 newPerfdata[0] = this.perfdataCalcPerc(oldPerfdata[i]);
                 if(!display_bits) {
                     newPerfdata[2] = this.perfdataCalcBytesReadable(oldPerfdata[i]);
@@ -821,7 +845,7 @@ var ElementLine = Element.extend({
                 }
                 foundNew = true;
             }
-            if(oldPerfdata[i][0] == 'out' && (oldPerfdata[i][2] === null || oldPerfdata[i][2] === '')) {
+            if(oldPerfdata[i][0] == line_label_out && (oldPerfdata[i][2] === null || oldPerfdata[i][2] === '')) {
                 newPerfdata[1] = this.perfdataCalcPerc(oldPerfdata[i]);
                 if(!display_bits) {
                     newPerfdata[3] = this.perfdataCalcBytesReadable(oldPerfdata[i]);
@@ -931,7 +955,7 @@ var ElementLine = Element.extend({
         // Break perfdata parts into array
         for (var i = 0; i < perfdataMatches.length; i++) {
             // Get parts of perfdata from string
-            var tmpSetMatches = perfdataMatches[i].match(/(&#145;)?([\w\s\=\']*)(&#145;)?\=([\d\.\-\+]*)([\w%]*)[\;|\s]?([\d\.\-:~@]+)*[\;|\s]?([\d\.\-:~@]+)*[\;|\s]?([\d\.\-\+]*)[\;|\s]?([\d\.\-\+]*)/);
+            var tmpSetMatches = perfdataMatches[i].match(/(&#145;)?([\w\s\=\'\-]*)(&#145;)?\=([\d\.\-\+]*)([\w%]*)[\;|\s]?([\d\.\-:~@]+)*[\;|\s]?([\d\.\-:~@]+)*[\;|\s]?([\d\.\-\+]*)[\;|\s]?([\d\.\-\+]*)/);
 
             // Check if we got any perfdata
             if (tmpSetMatches === null)
@@ -948,6 +972,147 @@ var ElementLine = Element.extend({
             ]);
         }
         return parsed;
-    }
+    },
+
+    /*
+     * There is a rectangle: viewport (current Leaflet map shown) + 10% on each side.
+     * This function cuts the lines protruding beyond the rectangle.
+     * Shortened lines prevent renderLine() from generating many vast <canvas> (10000-ish pixels) which eventually lead
+     * to memory exhaustion or crash the browser
+     *
+     * Returns:
+     *  either: [xA, yA, xB, yB] - original or adjusted line A/B coordinates,
+     *  or: null - line out of a rectangle, don't render
+     */
+
+    cutLineBeyondViewport: function(xA, yA, xB, yB) {
+        if (!g_map)
+            return([xA, yA, xB, yB]); // no viewport - no clipping
+
+        let viewport_size = g_map.getSize();
+        const xMax = viewport_size.x;  // 1920
+        const yMax = viewport_size.y;  // 1080
+        const xTolerance = xMax * 0.95; // 1824 (95%)
+        const yTolerance = yMax * 0.95; // 1026 (95%)
+
+        // Cohen-Sutherland algorithm
+
+        // region codes
+        const INSIDE = 0; // 0000
+        const LEFT = 1;   // 0001
+        const RIGHT = 2;  // 0010
+        const BOTTOM = 4; // 0100
+        const TOP = 8;    // 1000
+
+        // boundaries
+        const x_min = -xTolerance;
+        const x_max = xMax + xTolerance;
+        const y_min = -yTolerance;
+        const y_max = yMax + yTolerance;
+
+        // Function to compute region code
+        let regionCode = function (x, y)
+        {
+            let code = INSIDE;
+
+            if (x < x_min)       // to the left of rectangle
+                code |= LEFT;
+            else if (x > x_max)  // to the right of rectangle
+                code |= RIGHT;
+            if (y < y_min)       // below the rectangle
+                code |= BOTTOM;
+            else if (y > y_max)  // above the rectangle
+                code |= TOP;
+
+            return code;
+        }
+
+        let cohenSutherlandClip = function (x1, y1, x2, y2) {
+            let code1 = regionCode(x1, y1);
+            let code2 = regionCode(x2, y2);
+
+            let accept = false;
+
+            while (true)
+            {
+                if ((code1 == 0) && (code2 == 0))
+                {
+                    // If both endpoints lie within rectangle
+                    accept = true;
+                    break;
+                }
+                else if (code1 & code2)
+                {
+                    // If both endpoints are outside rectangle,
+                    // in same region
+                    break;
+                }
+                else
+                {
+                    // Some segment of line lies within the
+                    // rectangle
+                    let code_out;
+                    let x, y;
+
+                    // At least one endpoint is outside the
+                    // rectangle, pick it.
+                    if (code1 != 0)
+                        code_out = code1;
+                    else
+                        code_out = code2;
+
+                    // Find intersection point;
+                    // using formulas y = y1 + slope * (x - x1),
+                    // x = x1 + (1 / slope) * (y - y1)
+                    if (code_out & TOP)
+                    {
+                        // point is above the clip rectangle
+                        x = x1 + (x2 - x1) * (y_max - y1) / (y2 - y1);
+                        y = y_max;
+                    }
+                    else if (code_out & BOTTOM)
+                    {
+                        // point is below the rectangle
+                        x = x1 + (x2 - x1) * (y_min - y1) / (y2 - y1);
+                        y = y_min;
+                    }
+                    else if (code_out & RIGHT)
+                    {
+                        // point is to the right of rectangle
+                        y = y1 + (y2 - y1) * (x_max - x1) / (x2 - x1);
+                        x = x_max;
+                    }
+                    else if (code_out & LEFT)
+                    {
+                        // point is to the left of rectangle
+                        y = y1 + (y2 - y1) * (x_min - x1) / (x2 - x1);
+                        x = x_min;
+                    }
+
+                    // Now intersection point x,y is found
+                    // We replace point outside rectangle
+                    // by intersection point
+                    if (code_out == code1)
+                    {
+                        x1 = x;
+                        y1 = y;
+                        code1 = regionCode(x1, y1);
+                    }
+                    else
+                    {
+                        x2 = x;
+                        y2 = y;
+                        code2 = regionCode(x2, y2);
+                    }
+                }
+            }
+            if (accept)
+                return([x1, y1, x2, y2]);
+            else
+                return null;
+        }
+
+        return cohenSutherlandClip(xA, yA, xB, yB);
+    },
 
 });
