@@ -42,6 +42,7 @@ function _build_dsn_common($params) {
 class CorePDOHandler {
     private $DB = null;
     private $file = null;
+    private $dsn = null;
 
     // needs to be initialized after class declaration because directly
     // initializing it here is a syntax error in PHP 5.3
@@ -63,6 +64,7 @@ class CorePDOHandler {
                         .'WHERE users2roles."userId" = :id',
                     '-perm-rename-map' => 'UPDATE perms SET obj=:new_name '.
                         ' WHERE "mod"=\'Map\' AND obj=:old_name',
+                    '-perm-change-act' => 'UPDATE perms SET act=:new_act WHERE mod=:mod and act=:old_act',
 
                     '-role-add' => 'INSERT INTO roles (name) VALUES (:name)',
                     '-role-add-with-id' => 'INSERT INTO roles ("roleId", name) VALUES (:roleId, :name)',
@@ -128,6 +130,10 @@ class CorePDOHandler {
                 ),
 
                 'updates' => array(
+                    '1091500' => array(
+                        array('-perm-change-act', array('mod' => 'ChangePassword', 'old_act' => 'change', 'new_act' => '*'))
+                    ),
+
                     '1080600' => array(
                         array('-perm-add', array('mod' => 'Url', 'act' => 'view', 'obj' => '*')),
                         array('-create-pop-roles-perms-3', array(
@@ -261,6 +267,7 @@ class CorePDOHandler {
         }
         $drv_data = self::$DRIVERS[$driver];
         $dsn = "$driver:".$drv_data['build_dsn']($params);
+        $this->dsn = $dsn;
 
         try {
             $this->DB = new PDO($dsn, $username, $password, array(
@@ -270,12 +277,12 @@ class CorePDOHandler {
             ));
         } catch(PDOException $e) {
             error_log('Could not initialize a database connection: '.$e->getMessage());
+            $this->lastErrorInfo = $e->getMessage();
             return false;
-    	}
+        }
         if($this->DB === false || $this->DB === null)
             return false;
 
-        $this->dsn = $dsn;
         $this->driver = $driver;
         $this->data = $drv_data;
         $this->updating = false;
@@ -286,6 +293,7 @@ class CorePDOHandler {
                 $res = $this->DB->exec($q);
                 if($res === false) {
                     $this->DB = null;
+                    $this->lastErrorInfo = "Initial DB query ($q) failed";
                     return false;
                 }
             }
@@ -356,7 +364,7 @@ class CorePDOHandler {
         if (isset($this->lastErrorInfo))
             return $this->lastErrorInfo;
         else
-            return $this->DB->errorInfo();
+            return $this->DB ? $this->DB->errorInfo() : '';
     }
 
     public function errorString() {
@@ -460,7 +468,7 @@ class CorePDOHandler {
         try {
             ksort(self::$DRIVERS['_common']['updates']);
             foreach (self::$DRIVERS['_common']['updates'] as $ver => $queries) {
-                if (intval($ver) <= $dbVersion)
+                if (intval($ver) < $dbVersion)
                     continue;
 
                 if (!$this->inTrans) {
@@ -583,7 +591,7 @@ class CorePDOHandler {
         $this->queryFatal('-perm-add', array('mod' => 'User', 'act' => 'setOption', 'obj' => '*'));
 
         // Access controll: Change own password
-        $this->queryFatal('-perm-add', array('mod' => 'ChangePassword', 'act' => 'change', 'obj' => '*'));
+        $this->queryFatal('-perm-add', array('mod' => 'ChangePassword', 'act' => '*', 'obj' => '*'));
 
         // Access controll: View maps via multisite
         $this->queryFatal('-perm-add', array('mod' => 'Multisite', 'act' => 'getMaps', 'obj' => '*'));
@@ -618,7 +626,7 @@ class CorePDOHandler {
 
         // Access control: View URLs e.g. in rotation pools
         $this->queryFatal('-perm-add', array('mod' => 'Url', 'act' => 'view', 'obj' => '*'));
-        
+
         // Assign the new permission to the managers, users, guests
         $this->queryFatal('-create-pop-roles-perms-3', array(
             'r1' => 'Managers', 'r2' => 'Users (read-only)', 'r3' => 'Guests',
