@@ -54,18 +54,18 @@ define('MATCH_BOOLEAN', '/^(?:1|0)$/i');
 define('MATCH_BOOLEAN_EMPTY', '/^(?:1|0)*$/i');
 define('MATCH_LATLONG', '/^-?[0-9]+(.[0-9]+),-?[0-9]+(.[0-9]+)?$/');
 
-define('MATCH_COLOR', '/^(#?[0-9a-f]{3,6}|transparent)$/i');
+define('MATCH_COLOR', '/^(#?[0-9a-f]{3,8}|transparent)$/i');
 define('MATCH_OBJECTTYPE', '/^(?:global|host|service|dyngroup|aggr|hostgroup|servicegroup|map|textbox|shape|line|template|container)$/i');
 define('MATCH_OBJECTID', '/^(?:[a-z0-9]+)$/i');
 define('MATCH_OBJECTID_EMPTY', '/^(?:[a-z0-9]*)$/i');
-define('MATCH_PNGFILE', '/^([^\s]+)\.png$/i');
-define('MATCH_PNG_GIF_JPG_FILE', '/^([^\s]+)\.(png|gif|jpg)$/i');
-define('MATCH_PNG_GIF_JPG_FILE_OR_URL_NONE', '/^((.+)\.(png|gif|jpg)|\[[0-9a-z\s:+[\]()=%?&_.\-#@=\/\\\]+\]|none)$/i');
-define('MATCH_PNG_GIF_JPG_FILE_OR_URL', '/^((.+)\.(png|gif|jpg)|\[[0-9a-z\s:+[\]()=%?&_.\-#@=\/\\\]+\])$/i');
+define('MATCH_PNGFILE', '/^([^\s]+)\.png$/iu');
+define('MATCH_PNG_GIF_JPG_FILE', '/^([^\s]+)\.(png|gif|jpg)$/iu');
+define('MATCH_PNG_GIF_JPG_FILE_OR_URL_NONE', '/^((.+)\.(png|gif|jpg)|\[[0-9a-z\s:+[\]()=%?&_.\-#@=\/\\\]+\]|none)$/iu');
+define('MATCH_PNG_GIF_JPG_FILE_OR_URL', '/^((.+)\.(png|gif|jpg)|\[[0-9a-z\s:+[\]()=%?&_.\-#@=\/\\\]+\])$/iu');
 define('MATCH_ROTATION_STEP_TYPES_EMPTY', '/^(?:map|url)?$/');
 define('MATCH_LANGUAGE_EMPTY', '/^[a-zA-Z0-9\-_]*$/');
 define('MATCH_LANGUAGE_FILE', '/^([^.].*)/');
-define('MATCH_ICONSET', '/^(.+)_ok.(png|gif|jpg)$/');
+define('MATCH_ICONSET', '/^(.+)_ok.(png|gif|jpg)$/u');
 define('MATCH_BACKEND_FILE', '/^GlobalBackend([^MI].+)\.php$/');
 define('MATCH_BACKEND_ID', '/^[0-9a-z._-]*$/iu');
 define('MATCH_DOC_DIR', '/^([a-z]{2}_[A-Z]{2})/');
@@ -98,14 +98,14 @@ define('MATCH_ZOOM_FACTOR', '/^(?:[0-9]+|fill)$/');
 
 define('MATCH_URI_PART', '/^[a-zA-Z0-9_-]*$/');
 
-define('MATCH_CFG_FILE', '/^(.+)\.cfg$/');
-define('MATCH_CSV_FILE', '/^(.+)\.csv$/i');
-define('MATCH_MP3_FILE', '/^(.+)\.mp3$/i');
-define('MATCH_HEADER_TEMPLATE_FILE', '/^(.+)\.header\.html$/i');
-define('MATCH_HOVER_TEMPLATE_FILE', '/^(.+)\.hover\.html$/i');
-define('MATCH_CONTEXT_TEMPLATE_FILE', '/^(.+)\.context\.html$/i');
-define('MATCH_PHP_FILE', '/^(.+\.php)$/i');
-define('MATCH_SOURCE_FILE', '/^(.+)\.php$/i');
+define('MATCH_CFG_FILE', '/^(.+)\.cfg$/u');
+define('MATCH_CSV_FILE', '/^(.+)\.csv$/iu');
+define('MATCH_MP3_FILE', '/^(.+)\.mp3$/iu');
+define('MATCH_HEADER_TEMPLATE_FILE', '/^(.+)\.header\.html$/iu');
+define('MATCH_HOVER_TEMPLATE_FILE', '/^(.+)\.hover\.html$/iu');
+define('MATCH_CONTEXT_TEMPLATE_FILE', '/^(.+)\.context\.html$/iu');
+define('MATCH_PHP_FILE', '/^(.+\.php)$/iu');
+define('MATCH_SOURCE_FILE', '/^(.+)\.php$/iu');
 define('MATCH_INTEGER_PRESIGN', '/^[+-]?[0-9]+$/');
 define('MATCH_INTEGER_PRESIGN_EMPTY', '/^[+-]?[0-9]*$/');
 define('MATCH_LABEL_X', '/^([+-]?[0-9]+|center)$/');
